#[repr(u8)]pub enum Tcr2Bcp {
ACTIVE_HIGH = 0,
ACTIVE_LOW = 1,
}Variants
ACTIVE_HIGH = 0
Bit clock is active high with drive outputs on rising edge and sample inputs on falling edge.
ACTIVE_LOW = 1
Bit clock is active low with drive outputs on falling edge and sample inputs on rising edge.
Implementations